import subprocess
import shutil
import os
import sys

sourceName = "tema1.asm"
objName = "tema1.obj"
execName = "tema1.exe"

if sys.platform.startswith('win32'):
	sasmPath = "C:\\Program Files (x86)\\SASM"
	nasmPath = sasmPath + "\\NASM\\nasm.exe"
	gccPath = sasmPath + "\\MinGW\\bin\\gcc.exe"
else:
	nasmPath = "nasm"
	gccPath = "gcc"

assemblyOptions = "-g -f win32 -o " + objName + " " + sourceName
linkingOptions = objName + " -g -o " + execName + " -m32"
inputFileName = "input.inc"

print(nasmPath + " " + assemblyOptions)

numTests = 80
numPassed = 0

header = "======================= Tema 1 IOCLA ======================="
print("\n" + header + "\n")

for n in range(1, numTests + 1):
	shutil.copy("inputs/input" + str(n) + ".inc", inputFileName)

	return_code = subprocess.call(nasmPath + " " + assemblyOptions)
	if return_code != 0:
		result = "failed"
	else:
		return_code = subprocess.call(gccPath + " " + linkingOptions)
		
		if return_code != 0:
			result = "failed"
		else:
			proc = os.popen('.' + os.sep + 'tema1')
			result = proc.read().strip()
			proc.close()

			expectedResult = open("outputs/output" + str(n)).read()
			if expectedResult == result:
				result = "passed"
				numPassed += 1
			else:
				result = "failed"

	start = "Test " + str(n)
	print(start + "." * (len(header) - len(result) - len(start)) + result)

totalScore = "Result: " + str(numPassed) + "/" + str(numTests)
print("\n" + " " * (len(header) - len(totalScore)) + totalScore)

os.remove(objName)
os.remove(execName)
os.remove(inputFileName)